<!--
 * @Author: zouyaoji@https://github.com/zouyaoji
 * @Date: 2021-10-27 15:54:11
 * @LastEditTime: 2022-12-08 22:02:12
 * @LastEditors: zouyaoji
 * @Description:
 * @FilePath: \vue-cesium@next\website\docs\en-US\i18n.md
-->

## Internationalization

Vue for Cesium components are using Chinese **by default**, if you wish you use other languages, you can get you answer by keep reading.

### Global configuration

Vue for Cesium provides global configurations

```typescript
import { createApp } from 'vue'
import VueCesium from 'vue-cesium'
import enUS from 'vue-cesium/es/locale/lang/en-us'

const app = createApp(App)
app.use(VueCesium, {
  locale: enUS
})
app.mount('#app')
```

### VcConfigProvider

Vue for Cesium also provides a Vue component [VcConfigProvider](/#/en-US/component/vc-config-provider)
for globally configuring locale and other settings.

```html
<template>
  <vc-config-provider :locale="locale">
    <vc-viewer>
      <vc-navigation></vc-navigation>
    </vc-viewer>
  </vc-config-provider>
</template>

<script>
  import { defineComponent } from 'vue'
  import { VcConfigProvider, VcViewer, VcNavigation } from 'vue-cesium'

  import enUS from 'vue-cesium/es/locale/lang/en-us'

  export default defineComponent({
    components: {
      VcConfigProvider,
      VcViewer,
      VcNavigation
    },
    setup() {
      return {
        locale: enUS
      }
    }
  })
</script>
```

<!-- ### CDN Usage

If you are using VueCesium via CDN, then you need to do this, let's again take
unpkg as an example

```html
<script src="//unpkg.com/vue-cesium@next/dist/locale/zh-cn">
  app.use(VueCesium, {
    locale: VueCesium.lang.zh
  })
</script>
``` -->

[Supported Language List](https://github.com/zouyaoji/vue-cesium/tree/dev/packages/locale/lang)

<ul class="language-list">
  <li>Simplified Chinese (zh-hans)</li>
  <li>English (en-us)</li>
</ul>

If you need any other languages, [PR](https://github.com/zouyaoji/vue-cesium/pulls)
is always welcomed, you only need to add a language file at
[here](https://github.com/zouyaoji/vue-cesium/tree/dev/packages/locale/lang).
